severity        = 3
verbose         = 6
top             = 50
theme           = pbp || core || bugs || security || maintenance
criticism-fatal = 1
color           = 1
allow-unsafe    = 1
[-ClassHierarchies::ProhibitAutoloading]
[-Subroutines::ProhibitUnusedPrivateSubroutines]
